==> nextcloud-28.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/en_GB.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "Couldn't establish a federated share." : "Couldn't establish a federated share.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Couldn't establish a federated share, maybe the password was wrong.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federated Share request sent, you will receive an invitation. Check your notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "It is not allowed to send federated group shares from this server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sharing %1$s failed, because this item is already shared with the account %2$s",
    "Not allowed to create a federated share to the same account" : "Not allowed to create a federated share to the same account",
    "Federated shares require read permissions" : "Federated shares require read permissions",
    "File is already shared with %s" : "File is already shared with %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate.",
    "Could not find share" : "Could not find share",
    "Federated sharing" : "Federated sharing",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "You received {share} as a remote share from {user} (on behalf of {behalf})",
    "You received {share} as a remote share from {user}" : "You received {share} as a remote share from {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Sharing" : "Sharing",
    "Federated file sharing" : "Federated file sharing",
    "Provide federated file sharing across servers" : "Provide federated file sharing across servers",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
    "Allow people on this server to receive shares from other servers" : "Allow people on this server to receive shares from other servers",
    "Allow people on this server to send shares to groups on other servers" : "Allow people on this server to send shares to groups on other servers",
    "Allow people on this server to receive group shares from other servers" : "Allow people on this server to receive group shares from other servers",
    "Search global and public address book for people" : "Search global and public address book for people",
    "Allow people to publish their data to a global and public address book" : "Allow people to publish their data to a global and public address book",
    "Unable to update federated files sharing config" : "Unable to update federated files sharing config",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialogue. It looks like person@cloud.example.com",
    "Your Federated Cloud ID:" : "Your Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Add to your website",
    "Share with me via Nextcloud" : "Share with me via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Share with me through my #Nextcloud Federated Cloud ID, see {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud ID copied to the clipboard",
    "Copy to clipboard" : "Copy to clipboard",
    "Clipboard is not available" : "Clipboard is not available",
    "Copied!" : "Copied!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sharing %1$s failed, because this item is already shared with user %2$s",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Allow users on this server to send shares to groups on other servers" : "Allow users on this server to send shares to groups on other servers",
    "Allow users on this server to receive group shares from other servers" : "Allow users on this server to receive group shares from other servers",
    "Search global and public address book for users" : "Search global and public address book for users",
    "Allow users to publish their data to a global and public address book" : "Allow users to publish their data to a global and public address book"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/en_GB.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "Couldn't establish a federated share." : "Couldn't establish a federated share.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Couldn't establish a federated share, maybe the password was wrong.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federated Share request sent, you will receive an invitation. Check your notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "It is not allowed to send federated group shares from this server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sharing %1$s failed, because this item is already shared with the account %2$s",
    "Not allowed to create a federated share to the same account" : "Not allowed to create a federated share to the same account",
    "Federated shares require read permissions" : "Federated shares require read permissions",
    "File is already shared with %s" : "File is already shared with %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate.",
    "Could not find share" : "Could not find share",
    "Federated sharing" : "Federated sharing",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "You received {share} as a remote share from {user} (on behalf of {behalf})",
    "You received {share} as a remote share from {user}" : "You received {share} as a remote share from {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Sharing" : "Sharing",
    "Federated file sharing" : "Federated file sharing",
    "Provide federated file sharing across servers" : "Provide federated file sharing across servers",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
    "Allow people on this server to receive shares from other servers" : "Allow people on this server to receive shares from other servers",
    "Allow people on this server to send shares to groups on other servers" : "Allow people on this server to send shares to groups on other servers",
    "Allow people on this server to receive group shares from other servers" : "Allow people on this server to receive group shares from other servers",
    "Search global and public address book for people" : "Search global and public address book for people",
    "Allow people to publish their data to a global and public address book" : "Allow people to publish their data to a global and public address book",
    "Unable to update federated files sharing config" : "Unable to update federated files sharing config",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialogue. It looks like person@cloud.example.com",
    "Your Federated Cloud ID:" : "Your Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (formerly Twitter)",
    "formerly Twitter" : "formerly Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Add to your website",
    "Share with me via Nextcloud" : "Share with me via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Share with me through my #Nextcloud Federated Cloud ID, see {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud ID copied to the clipboard",
    "Copy to clipboard" : "Copy to clipboard",
    "Clipboard not available. Please copy the cloud ID manually." : "Clipboard not available. Please copy the cloud ID manually.",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Sharing %1$s failed, because this item is already shared with user %2$s",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Allow users on this server to send shares to groups on other servers" : "Allow users on this server to send shares to groups on other servers",
    "Allow users on this server to receive group shares from other servers" : "Allow users on this server to receive group shares from other servers",
    "Search global and public address book for users" : "Search global and public address book for users",
    "Allow users to publish their data to a global and public address book" : "Allow users to publish their data to a global and public address book",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "Clipboard is not available",
    "Copied!" : "Copied!"
},
"nplurals=2; plural=(n != 1);");
